@@ -7,6 +7,7 @@ from __future__ import absolute_import
 
 import unittest
 
+import mock.mock as mock
 import requests
 
 import pythesint as pti
@@ -25,20 +26,18 @@ class GCMDVocabularyTest(unittest.TestCase):
                 '/instruments/?format=xml"')
         pti.gcmd_vocabulary._read_revision(line, gcmd_list)
         self.assertEqual(len(gcmd_list), 1)
-        self.assertDictEqual(gcmd_list[0], {'Revision': '2016-01-08 13:40:40'})
+        self.assertDictEqual(
+            gcmd_list[0],
+            {'Keyword Version': '8.1', 'Revision': '2016-01-08 13:40:40'})
 
     def test_check_categories(self):
-        line = ('Category,Class,Type,Subtype,Short_Name,Long_Name,UUID')
+        lines = [
+            'Revision',
+            'Category,Class,Type,Subtype,Short_Name,Long_Name,UUID'
+        ]
         categories = ['Category', 'Class', 'Type', 'Subtype', 'Short_Name',
                       'Long_Name']
-        pti.gcmd_vocabulary._check_categories(line, categories)
-
-    def test_check_categories_wrong(self):
-        line = ('Category,Class,Type,Subtype,Short_Name,Long_Name,UUID')
-        categories = ['Category', 'Type', 'Class', 'Subtype', 'Short_Name',
-                      'Long_Name']
-        with self.assertRaises(TypeError):
-            pti.gcmd_vocabulary._check_categories(line, categories)
+        self.assertListEqual(pti.gcmd_vocabulary._get_categories(lines), categories)
 
     def test_read_line_simple(self):
         gcmd_list = [{'Revision': '2016-01-08 13:40:40'}]
@@ -107,6 +106,30 @@ class GCMDVocabularyTest(unittest.TestCase):
         with self.assertRaises(requests.RequestException):
             voc._fetch_online_data()
 
+    def test_fetch_version(self):
+        """Test that the specified version is fetched"""
+        voc = GCMDVocabulary(name='test_voc', url='https://sdfghdfghd.nersc.no')
+        # We use the exception as side effect to skip the part of the
+        # method we are not testing.
+        # TODO: split _fetch_online_data() into several methods instead
+        with mock.patch('requests.get', side_effect=requests.RequestException) as mock_get:
+            with self.assertRaises(requests.RequestException):
+                voc._fetch_online_data()
+            mock_get.assert_called_with('https://sdfghdfghd.nersc.no', verify=False, params={})
+
+            with self.assertRaises(requests.RequestException):
+                voc._fetch_online_data(version=None)
+            mock_get.assert_called_with('https://sdfghdfghd.nersc.no', verify=False, params={})
+
+            with self.assertRaises(requests.RequestException):
+                voc._fetch_online_data(version='')
+            mock_get.assert_called_with('https://sdfghdfghd.nersc.no', verify=False, params={})
+
+            with self.assertRaises(requests.RequestException):
+                voc._fetch_online_data(version='9.1.5')
+            mock_get.assert_called_with(
+                'https://sdfghdfghd.nersc.no', verify=False, params={'version': '9.1.5'})
+
 if __name__ == "__main__":
     # import sys;sys.argv = ['', 'Test.testName']
     unittest.main()
